@@ -42,5 +42,5 @@ NanoPlot --fasta nanotest/reads.fa.gz --verbose --maxlength 35000
 echo ""
 echo ""
 echo ""
-echo "testing feather:"
-NanoPlot --feather nanotest/summary1.feather --verbose --outdir plots
+# echo "testing feather:"
+# NanoPlot --feather nanotest/summary1.feather --verbose --outdir plots
